aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs')
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs16
1 files changed, 5 insertions, 11 deletions
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
index 950b8d23f..c4e82b7d2 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
@@ -1,7 +1,6 @@
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
-using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
@@ -24,24 +23,19 @@ namespace Tango.PPC.Common.Notifications
ObservableCollection<NotificationItem> NotificationItems { get; }
/// <summary>
- /// Gets the notification items view.
- /// </summary>
- ICollectionView NotificationItemsView { get; }
-
- /// <summary>
/// Gets the collection of taskbar items.
/// </summary>
ObservableCollection<TaskBarItem> TaskBarItems { get; }
/// <summary>
/// Gets the application bar items.
/// </summary>
- ObservableCollection<AppBarItem> AppBarItems { get; }
+ AppBarItem CurrentAppBarItem { get; }
/// <summary>
- /// Gets a value indicating whether this instance has any application bar items.
+ /// Gets a value indicating whether this instance has application bar item.
/// </summary>
- bool HasAppBarItems { get; }
+ bool HasAppBarItem { get; }
/// <summary>
/// Gets a value indicating whether this instance has notification items.
@@ -182,7 +176,7 @@ namespace Tango.PPC.Common.Notifications
/// </summary>
/// <typeparam name="T"></typeparam>
/// <returns></returns>
- T PushAppBarItem<T>() where T : AppBarItem;
+ AppBarItem PushAppBarItem<T>() where T : AppBarItem;
/// <summary>
/// Pops the application bar item.
@@ -24,24 +23,19 @@ namespace Tango.PPC.Common.Notifications
ObservableCollection<TaskBarItem> TaskBarItems { get; }
/// <summary>
- /// Gets the application bar items.
+ /// Gets the current application bar item.
/// </summary>